Actions, Resources, and Condition Keys for AWS RoboMaker - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS RoboMaker.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for AWS RoboMaker

AWS RoboMaker (service prefix: `robomaker`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS RoboMaker
- Resources Defined by AWS RoboMaker
- Condition Keys for AWS RoboMaker

## Actions Defined by AWS RoboMaker

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
BatchDescribeSimulationJob | Describe multiple simulation jobs | Read |  |  |
CancelDeploymentJob | Cancel a deployment job | Write | deploymentJob* |  |
CancelSimulationJob | Cancel a simulation job | Write | simulationJob* |  |
CreateDeploymentJob | Create a deployment job | Write |  | aws:TagKeys aws:RequestTag/${TagKey} | iam:CreateServiceLinkedRole
CreateFleet | Create a deployment fleet that represents a logical group of robots running the same robot application | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreateRobot | Create a robot that can be registered to a fleet | Write |  | aws:TagKeys aws:RequestTag/${TagKey} | iam:CreateServiceLinkedRole
CreateRobotApplication | Create a robot application | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreateRobotApplicationVersion | Create a snapshot of a robot application | Write | robotApplication* |  | s3:GetObject
CreateSimulationApplication | Create a simulation application | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreateSimulationApplicationVersion | Create a snapshot of a simulation application | Write | simulationApplication* |  | s3:GetObject
CreateSimulationJob | Create a simulation job | Write |  | aws:TagKeys aws:RequestTag/${TagKey} | iam:CreateServiceLinkedRole
DeleteFleet | Delete a deployment fleet | Write | deploymentFleet* |  |
DeleteRobot | Delete a robot | Write | robot* |  |
DeleteRobotApplication | Delete a robot application | Write | robotApplication* |  |
DeleteSimulationApplication | Delete a simulation application | Write | simulationApplication* |  |
DeregisterRobot | Deregister a robot from a fleet | Write | deploymentFleet* |  |
robot* |  |
DescribeDeploymentJob | Describe a deployment job | Read | deploymentJob* |  |
DescribeFleet | Describe a deployment fleet | Read | deploymentFleet* |  |
DescribeRobot | Describe a robot | Read | robot* |  |
DescribeRobotApplication | Describe a robot application | Read | robotApplication* |  |
DescribeSimulationApplication | Describe a simulation application | Read | simulationApplication* |  |
DescribeSimulationJob | Describe a simulation job | Read | simulationJob* |  |
ListDeploymentJobs | List deployment jobs | List |  |  |
ListFleets | List fleets | List |  |  |
ListRobotApplications | List robot applications | List |  |  |
ListRobots | List robots | List |  |  |
ListSimulationApplications | List simulation applications | List |  |  |
ListSimulationJobs | List simulation jobs | List |  |  |
ListTagsForResource | List tags for a RoboMaker resource. | List | deploymentFleet |  |
deploymentJob |  |
robot |  |
robotApplication |  |
simulationApplication |  |
simulationJob |  |
RegisterRobot | Register a robot to a fleet | Write | deploymentFleet* |  |
robot* |  |
RestartSimulationJob | Restart a running simulation job | Write | simulationJob* |  |
SyncDeploymentJob | Ensures the most recently deployed robot application is deployed to all robots in the fleet | Write | deploymentFleet* |  | iam:CreateServiceLinkedRole
TagResource | Add tags to a RoboMaker resource | Write | deploymentFleet |  |
deploymentJob |  |
robot |  |
robotApplication |  |
simulationApplication |  |
simulationJob |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Remove tags from a RoboMaker resource | Write | deploymentFleet |  |
deploymentJob |  |
robot |  |
robotApplication |  |
simulationApplication |  |
simulationJob |  |
| aws:TagKeys |
UpdateRobotApplication | Update a robot application | Write | robotApplication* |  |
UpdateSimulationApplication | Update a simulation application | Write | simulationApplication* |  |

## Resources Defined by AWS RoboMaker

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
robotApplication | `arn:${Partition}:robomaker:${Region}:${Account}:robot-application/${ApplicationName}/${CreatedOnEpoch}` | aws:ResourceTag/${TagKey}
simulationApplication | `arn:${Partition}:robomaker:${Region}:${Account}:simulation-application/${ApplicationName}/${CreatedOnEpoch}` | aws:ResourceTag/${TagKey}
simulationJob | `arn:${Partition}:robomaker:${Region}:${Account}:simulation-job/${SimulationJobId}` | aws:ResourceTag/${TagKey}
deploymentJob | `arn:${Partition}:robomaker:${Region}:${Account}:deployment-job/${DeploymentJobId}` | aws:ResourceTag/${TagKey}
robot | `arn:${Partition}:robomaker:${Region}:${Account}:robot/${RobotName}/${CreatedOnEpoch}` | aws:ResourceTag/${TagKey}
deploymentFleet | `arn:${Partition}:robomaker:${Region}:${Account}:deployment-fleet/${FleetName}/${CreatedOnEpoch}` | aws:ResourceTag/${TagKey}

## Condition Keys for AWS RoboMaker

AWS RoboMaker defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} |  | String
aws:ResourceTag/${TagKey} |  | String
aws:TagKeys |  | String

On this page:

- Actions Defined by AWS RoboMaker
- Resources Defined by AWS RoboMaker
- Condition Keys for AWS RoboMaker

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more